# SLIP-0044 : Registered coin types for BIP-0044

```
Number:  SLIP-0044
Title:   Registered coin types for BIP-0044
Type:    Standard
Status:  Draft
Authors: Pavol Rusnak <stick@satoshilabs.com>
         Marek Palatinus <slush@satoshilabs.com>
Created: 2014-07-09
```

## Abstract

BIP-0044 defines a logical hierarchy for deterministic wallets.
Level 2 of the hierarchy describes a coin type in use.

## Motivation

BIP repository does not want to deal with assigning the values for various
coin types different than Bitcoin so we propose this SLIP to become such body.

## Registered coin types

These are the registered coin types for usage in level 2 of BIP44 described in chapter "Coin type".

All these constants are used as hardened derivation.

index | hexa       | coin
------|------------|-----------------------------------
0     | 0x80000000 | [Bitcoin](https://bitcoin.org/)
1     | 0x80000001 | Testnet (all coins)
2     | 0x80000002 | [Litecoin](https://litecoin.org/)
3     | 0x80000003 | [Dogecoin](https://github.com/dogecoin/dogecoin)
4     | 0x80000004 | Reddcoin
5     | 0x80000005 | [Dash](https://github.com/dashpay/dash) (ex Darkcoin)
6     | 0x80000006 | [Peercoin](https://peercoin.net/)
7     | 0x80000007 | [Namecoin](http://namecoin.info/)
8     | 0x80000008 | [Feathercoin](https://www.feathercoin.com/)
9     | 0x80000009 | [Counterparty](http://counterparty.io/)
10    | 0x8000000a | [Blackcoin](http://blackcoin.co/)
11    | 0x8000000b | [NuShares](https://nubits.com/nushares/introduction)
12    | 0x8000000c | NuBits
13    | 0x8000000d | Mazacoin
14    | 0x8000000e | Viacoin
15    | 0x8000000f | ClearingHouse
16    | 0x80000010 | Rubycoin
17    | 0x80000011 | Groestlcoin
18    | 0x80000012 | Digitalcoin
19    | 0x80000013 | Cannacoin
20    | 0x80000014 | DigiByte
21    | 0x80000015 | [Open Assets](https://github.com/OpenAssets/open-assets-protocol)
22    | 0x80000016 | Monacoin
23    | 0x80000017 | Clams
24    | 0x80000018 | Primecoin
25    | 0x80000019 | Neoscoin
26    | 0x8000001a | Jumbucks
27    | 0x8000001b | ziftrCOIN
28    | 0x8000001c | Vertcoin
29    | 0x8000001d | NXT
30    | 0x8000001e | Burst
31    | 0x8000001f | MonetaryUnit
32    | 0x80000020 | Zoom
33    | 0x80000021 | Vpncoin
34    | 0x80000022 | [Canada eCoin](https://github.com/Canada-eCoin/)
35    | 0x80000023 | ShadowCash
36    | 0x80000024 | [ParkByte](https://github.com/parkbyte/)
37    | 0x80000025 | Pandacoin
38    | 0x80000026 | StartCOIN
39    | 0x80000027 | [MOIN](https://discovermoin.com)
40    | 0x80000028 | [Expanse](http://www.expanse.tech/)
45    | 0x8000002D | [Argentum](http://www.argentum.io)
49    | 0x80000031 | Global Currency Reserve (GCRcoin)
50    | 0x80000032 | [Novacoin](https://github.com/novacoin-project/novacoin)
51    | 0x80000033 | [Asiacoin](https://github.com/AsiaCoin/AsiaCoinFix)
52    | 0x80000034 | [Bitcoindark](https://github.com/jl777/btcd)
53    | 0x80000035 | [Dopecoin](https://github.com/dopecoin-dev/DopeCoinV3)
54    | 0x80000036 | [Templecoin](https://github.com/9cat/templecoin)
55    | 0x80000037 | [AIB](https://github.com/iobond/aib)
56    | 0x80000038 | [EDRCoin](https://github.com/EDRCoin/EDRcoin-src)
57    | 0x80000039 | [Syscoin](https://github.com/syscoin/syscoin2)
58    | 0x8000003a | [Solarcoin](https://github.com/onsightit/solarcoin)
59    | 0x8000003b | [Smileycoin](https://github.com/tutor-web/smileyCoin)
60    | 0x8000003c | [Ether](https://ethereum.org/ether)
61    | 0x8000003d | [Ether Classic](https://ethereumclassic.github.io)
62    | 0x8000003e | [Pesobit](https://github.com/pesobitph/pesobit-source)
64    | 0x80000040 | [Open Chain](https://github.com/openchain/)
69    | 0x80000045 | [OKCash](https://github.com/okcashpro/)
77    | 0x8000004d | [DogecoinDark](https://github.com/doged/)
78    | 0x8000004e | [Electronic Gulden](https://egulden.org/)
79    | 0x8000004f | [ClubCoin](https://clubcoin.co/)
80    | 0x80000050 | [RichCoin](https://richcoin.us/)
81    | 0x80000051 | [Potcoin](http://potcoin.com/)
82    | 0x80000052 | Quarkcoin
83    | 0x80000053 | Terracoin
84    | 0x80000054 | Gridcoin
85    | 0x80000055 | [Auroracoin](http://auroracoin.is/)
86    | 0x80000056 | IXCoin
87    | 0x80000057 | [Gulden](https://Gulden.com/)
88    | 0x80000058 | [BitBean](http://bitbean.org/)
89    | 0x80000059 | [Bata](http://bata.io/)
90    | 0x8000005a | [Myriadcoin](http://myriadcoin.org)
91    | 0x8000005b | [BitSend](http://bitsend.info)
92    | 0x8000005c | [Unobtanium](http://http://unobtanium.uno/)
93    | 0x8000005d | [MasterTrader](https://github.com/CrypticApplications/MTR-Update/)
94    | 0x8000005e | [GoldBlocks](https://github.com/goldblockscoin/goldblocks)
95    | 0x8000005f | [Saham](https://github.com/SahamDev/SahamDev)
96    | 0x80000060 | [Chronos](https://github.com/chronoscoin/Chronoscoin)
97    | 0x80000061 | [Ubiquoin](https://github.com/ubiquoin/ubiq)
98    | 0x80000062 | [Evotion](https://github.com/evoshiun/Evotion)
99    | 0x80000063 | [SaveTheOcean](https://github.com/SaveTheOceanMovement/SaveTheOceanCoin)
100   | 0x80000064 | [BigUp](https://github.com/BigUps/)
101   | 0x80000065 | [GameCredits](https://github.com/gamecredits-project)
102   | 0x80000066 | [Dollarcoins](https://github.com/dollarcoins/source)
103   | 0x80000067 | [Zayedcoin](https://github.com/ZayedCoin/Zayedcoin)
104   | 0x80000068 | [Dubaicoin](https://github.com/DubaiCoinDev/DubaiCoin)
105   | 0x80000069 | [Stratis](http://www.stratisplatform.com)
106   | 0x8000006a | [Shilling](https://github.com/yavwa/Shilling)
118   | 0x80000076 | [PiggyCoin](https://www.piggy-coin.com/)
119   | 0x80000077 | [Pivx (PIVX)](https://github.com/PIVX-Project/PIVX)
128   | 0x80000080 | [Monero](https://getmonero.org/)
130   | 0x80000082 | [NavCoin](https://github.com/navcoindev/navcoin2)
131   | 0x80000083 | [Factom Factoids](https://github.com/FactomProject/FactomDocs/blob/master/wallet_info/wallet_test_vectors.md)
132   | 0x80000084 | [Factom Entry Credits](https://github.com/FactomProject)
133   | 0x80000085 | [Zcash](https://z.cash)
134   | 0x80000086 | [Lisk](https://lisk.io/)
135   | 0x80000087 | [Steem](http://steem.io)
136   | 0x80000088 | [ZCoin](https://zcoin.tech)
137   | 0x80000089 | [Rootstock](http://www.rsk.co/)
138   | 0x8000008A | [Giftblock](https://github.com/gyft/giftblock)
139   | 0x8000008B | [RealPointCoin](https://github.com/MaxSmile/RealPointCoinQt)
140   | 0x8000008C | [LBRY Credits (LBC)](https://lbry.io/)
141   | 0x8000008D | [Komodo (KMD)](https://komodoplatform.com/)
142   | 0x8000008E | [bisq Token (BSQ)](http://bisq.io/)
37310 | 0x800091BE | [Rootstock Testnet](http://www.rsk.co/)

Coin types will be added only if there is a wallet implementing BIP-0044 for desired coin.

## Libraries

* [BIP44-constants](https://www.npmjs.com/package/bip44-constants) ([source](http://github.com/bitcoinjs/bip44-constants)) JavaScript package with described coin types

## References

* [BIP-0044: Multi-Account Hierarchy for Deterministic Wallets](https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki)
